#    Copyright (C) 1999 Aladdin Enterprises.  All rights reserved.
# 
# This file is part of GNU Ghostscript.
# 
# GNU Ghostscript is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY.  No author or distributor accepts responsibility to
# anyone for the consequences of using it or for whether it serves any
# particular purpose or works at all, unless he says so in writing.  Refer to
# the GNU General Public License for full details.
# 
# Everyone is granted permission to copy, modify and redistribute GNU
# Ghostscript, but only under the conditions described in the GNU General
# Public License.  A copy of this license is supposed to have been given to
# you along with GNU Ghostscript so you can know your rights and
# responsibilities.  It should be in a file named COPYING.  Among other
# things, the copyright notice and this notice must be preserved on all
# copies.
# 
# Aladdin Enterprises supports the work of the GNU Project, but is not
# affiliated with the Free Software Foundation or the GNU Project.  GNU
# Ghostscript, as distributed by Aladdin Enterprises, does not require any GNU
# software to build or run it.

# $Id: gnudevs.mak $
# makefile for GPL'ed device drivers and features.

# Define the name of this makefile.
GNUDEVS_MAK=$(GLSRC)gnudevs.mak

###### -------------------------- Features -------------------------- ######

# GNU readline.  This code was contributed by a user: please contact
# Alexey Subbotin <A.Subbotin@lpi.ru> if you have questions.
# The references from a gp_ module to the interpreter are a bug,
# but they are intrinsic to what this implementation does.
#
# In order to use GNU readline, you must add $(PSD)gnrdline to the
# definition of FEATURE_DEVS in your top-level makefile.
#
# If you want to use the GNU readline package with AIX, you must change
# the mention of termcap to curses in the line a few lines below here.

gnrdline_=$(PSOBJ)gp_gnrdl.$(OBJ)
$(PSD)gnrdline.dev : $(INT_MAK) $(ECHOGS_XE) $(gnrdline_)
	$(SETMOD) $(PSD)gnrdline $(gnrdline_)
	$(ADDMOD) $(PSD)gnrdline -lib readline termcap
	$(ADDMOD) $(PSD)gnrdline -replace $(GLD)strdline
	$(ADDMOD) $(PSD)gnrdline -ps gs_rdlin

$(PSOBJ)gp_gnrdl.$(OBJ) : $(PSSRC)gp_gnrdl.c $(AK)\
 $(ctype__h) $(malloc__h) $(memory__h) $(string__h)\
 $(gp_h) $(gscdefs_h) $(gsmalloc_h) $(gsmemory_h) $(gsstruct_h)\
 $(gxiodev_h) $(stream_h)\
 $(ghost_h) $(dstack_h) $(errors_h) $(ialloc_h) $(idict_h) $(iname_h) $(iutil_h)\
 $(ostack_h)
	$(PSCC) $(PSO_)gp_gnrdl.$(OBJ) $(C_) $(PSSRC)gp_gnrdl.c

###### --------------------------- Drivers -------------------------- ######

# The following drivers are licensed with the GNU General Public License.
# They are user-contributed, and maintained (if at all) by users.
# Please do not ask Aladdin any questions about these drivers: if you have
# questions, please contact the author or contact person listed next to
# the entry for the device.

# Displays:
#   Platform-independent:
#	sxlcrt	CRT sixels, e.g. for VT240-like terminals
# Printers:
#	dl2100	DEC DEClaser 2100 printer
#	la50	DEC LA50 printer
#	la70	DEC LA70 printer
#	la75	DEC LA75 printer
#	la75plus DEC LA75plus printer
#	ln03	DEC LN03 printer
#	oki4w	Okidata OkiPage 4w+ LED printer
#	xes	Xerox XES printers (2700, 3700, 4045, etc.)

### ------------------------- DEC sixel displays ------------------------ ###

# Author: Phil Keegstra (keegstra@tonga.gsfc.nasa.gov)
# Device: DEC sixel displays
# This is a "printer" device, but it probably shouldn't be.
# I don't know why the implementor chose to do it this way.
sxlcrt_=$(GLOBJ)gdevln03.$(OBJ)
$(DD)sxlcrt.dev : $(sxlcrt_) $(DD)page.dev
	$(SETPDEV) $(DD)sxlcrt $(sxlcrt_)

### -------- The DEC LN03/DL2100/LA50/LA70/LA75 printer devices -------- ###

ln03_=$(GLOBJ)gdevln03.$(OBJ)

# Author: Ulrich Mueller (ulm@vsnhd1.cern.ch)
# Printer: DEC LN03
$(DD)ln03.dev : $(ln03_) $(DD)page.dev
	$(SETPDEV) $(DD)ln03 $(ln03_)

# Author: Nick Brown (nick.brown@coe.int)
# Printer: DEClaser 2100
$(DD)dl2100.dev : $(ln03_) $(DD)page.dev
	$(SETPDEV) $(DD)dl2100 $(ln03_)

# Author: Ian MacPhedran (macphed@dvinci.USask.CA)
# Printer: DEC LA50
$(DD)la50.dev : $(ln03_) $(DD)page.dev
	$(SETPDEV) $(DD)la50 $(ln03_)

# Author: Bruce Lowekamp (lowekamp@csugrad.cs.vt.edu)
# Printer: DEC LA70
$(DD)la70.dev : $(ln03_) $(DD)page.dev
	$(SETPDEV) $(DD)la70 $(ln03_)

# Author: Ian MacPhedran (macphed@dvinci.USask.CA)
# Printer: DEC LA75
$(DD)la75.dev : $(ln03_) $(DD)page.dev
	$(SETPDEV) $(DD)la75 $(ln03_)

# Author: Andre' Beck (Andre_Beck@IRS.Inf.TU-Dresden.de)
# Printer: DEC LA75plus
$(DD)la75plus.dev : $(ln03_) $(DD)page.dev
	$(SETPDEV) $(DD)la75plus $(ln03_)

$(GLOBJ)gdevln03.$(OBJ) : $(GLSRC)gdevln03.c $(PDEVH)
	$(GLCC) $(GLO_)gdevln03.$(OBJ) $(C_) $(GLSRC)gdevln03.c

### ----------------- The Okidata OkiPage 4w+ device ------------------- ###

oki4w_=$(GLOBJ)gdevop4w.$(OBJ)
$(DD)oki4w.dev : $(oki4w_) $(DD)page.dev
	$(SETPDEV) $(DD)oki4w $(oki4w_)

# Author: Ivan Schreter (ivan@shadow.sk)
# Printer: Okidata OkiPage 4w+
$(GLOBJ)gdevop4w.$(OBJ) : $(GLSRC)gdevop4w.c $(PDEVH)
	$(GLCC) $(GLO_)gdevop4w.$(OBJ) $(C_) $(GLSRC)gdevop4w.c

### ----------------- The Xerox XES printer device --------------------- ###

xes_=$(GLOBJ)gdevxes.$(OBJ)
$(DD)xes.dev : $(xes_) $(DD)page.dev
	$(SETPDEV) $(DD)xes $(xes_)

# Author: Peter Flass (flass@lbdrscs.bitnet)
# Printer: Xerox XES (2700, 3700, 4045, etc.)
$(GLOBJ)gdevxes.$(OBJ) : $(GLSRC)gdevxes.c $(PDEVH)
	$(GLCC) $(GLO_)gdevxes.$(OBJ) $(C_) $(GLSRC)gdevxes.c
